====
tree
====

This product contains the definition(s) of the SAS tree(s).
On installation it installs multiple tree definitions in a
manner that can be easily sourced or setup by users.

See https://trac.sdss.org/wiki/DataArchive/TreeProduct
